@@ -165,7 +165,7 @@ class Panel(ScreenPanel):
         self.buttons['rm'] = self._gtk.Button("bed-level-r-m", scale=button_scale)
         self.buttons['fm'] = self._gtk.Button("bed-level-b-m", scale=button_scale)
         self.buttons['bm'] = self._gtk.Button("bed-level-t-m", scale=button_scale)
-        self.buttons['center'] = self._gtk.Button("increase", scale=button_scale)
+        self.buttons['center'] = self._gtk.Button("increase", scale=button_scale / 2)
 
         bedgrid = Gtk.Grid()
 
@@ -290,22 +290,26 @@ class Panel(ScreenPanel):
                 'lm': lm
             }
         self.screw_dict['center'] = center
+        remove_list = []
+        for screw in self.screw_dict:
+            if screw not in screw_positions:
+                remove_list.append(screw)
+        for screw in remove_list:
+            self.screw_dict.pop(screw)
+
         grid.attach(bedgrid, 1, 0, 3, 2)
         self.content.add(grid)
 
-    def activate(self):
-        for key, value in self.screw_dict.items():
-            self.buttons[key].set_label(f"{value}")
-
     def home(self):
         # Test if all axes have been homed. Home if necessary.
         if self._printer.get_stat("toolhead", "homed_axes") != "xyz":
-            self._screen._ws.klippy.gcode_script(KlippyGcodes.HOME)
+            self._screen._ws.klippy.gcode_script("G28")
             # do Z_TILT_CALIBRATE if applicable.
             if self._printer.config_section_exists("z_tilt"):
-                self._screen._ws.klippy.gcode_script(KlippyGcodes.Z_TILT)
+                self._screen._ws.klippy.gcode_script("Z_TILT_ADJUST")
 
     def go_to_position(self, widget, position):
+        widget.set_sensitive(False)
         self.home()
         logging.debug(f"Going to position: {position}")
         script = [
@@ -314,15 +318,10 @@ class Panel(ScreenPanel):
             f"G1 X{position[0]} Y{position[1]} F{self.horizontal_speed * 60}\n",
             f"G1 Z{self.probe_z_height} F{self.lift_speed * 60}\n"
         ]
-
-        self._screen._ws.klippy.gcode_script(
-            "\n".join(script)
-        )
+        self._screen._send_action(widget, "printer.gcode.script", {"script": "\n".join(script)})
 
     def disable_motors(self, widget):
-        self._screen._ws.klippy.gcode_script(
-            "M18"  # Disable motors
-        )
+        self._screen._send_action(widget, "printer.gcode.script", {"script": "M18"})
 
     def process_busy(self, busy):
         for button in self.buttons:
@@ -401,7 +400,8 @@ class Panel(ScreenPanel):
         return sorted(screws, key=lambda s: (float(s[1]), float(s[0])))
 
     def screws_tilt_calculate(self, widget):
+        widget.set_sensitive(False)
         self.home()
         self.response_count = 0
         self.buttons['screws'].set_sensitive(False)
-        self._screen._ws.klippy.gcode_script("SCREWS_TILT_CALCULATE")
+        self._screen._send_action(widget, "printer.gcode.script", {"script": "SCREWS_TILT_CALCULATE"})
