@@ -47,10 +47,6 @@ class Panel(ScreenPanel):
         while len(self.menu) > 1:
             self.unload_menu()
         self.reload_macros()
-        self._screen.base_panel.toggle_macro_shorcut_sensitive(False)
-
-    def deactivate(self):
-        self._screen.base_panel.toggle_macro_shorcut_sensitive(True)
 
     def add_gcode_macro(self, macro):
         # Support for hiding macros by name
@@ -111,9 +107,9 @@ class Panel(ScreenPanel):
         for param in self.macros[macro]["params"]:
             value = self.macros[macro]["params"][param].get_text()
             if value:
-                params += f'{param}={value} '
+                params += f' {param}={value}'
         self._screen.show_popup_message(f"{macro} {params}", 1)
-        self._screen._ws.klippy.gcode_script(f"{macro} {params}")
+        self._screen._send_action(widget, "printer.gcode.script", {"script": f"{macro}{params}"})
 
     def change_sort(self, widget):
         self.sort_reverse ^= True
