@@ -3,7 +3,6 @@ import gi
 
 gi.require_version("Gtk", "3.0")
 from gi.repository import Gtk, Pango
-from ks_includes.KlippyGcodes import KlippyGcodes
 from ks_includes.screen_panel import ScreenPanel
 
 
@@ -108,17 +107,15 @@ class Panel(ScreenPanel):
     def start_calibration(self, widget, method):
         self.labels['popover'].popdown()
         if self._printer.get_stat("toolhead", "homed_axes") != "xyz":
-            self._screen._ws.klippy.gcode_script(KlippyGcodes.HOME)
+            self._screen._ws.klippy.gcode_script("G28")
         self.calibrating_axis = method
         if method == "x":
-            self._screen._ws.klippy.gcode_script('SHAPER_CALIBRATE AXIS=X')
+            self._screen._send_action(self.calibrate_btn, "printer.gcode.script", {"script": 'SHAPER_CALIBRATE AXIS=X'})
         if method == "y":
-            self._screen._ws.klippy.gcode_script('SHAPER_CALIBRATE AXIS=Y')
+            self._screen._send_action(self.calibrate_btn, "printer.gcode.script", {"script": 'SHAPER_CALIBRATE AXIS=Y'})
         if method == "both":
-            self._screen._ws.klippy.gcode_script('SHAPER_CALIBRATE')
-
+            self._screen._send_action(self.calibrate_btn, "printer.gcode.script", {"script": 'SHAPER_CALIBRATE'})
         self.calibrate_btn.set_label(_('Calibrating') + '...')
-        self.calibrate_btn.set_sensitive(False)
 
     def set_opt_value(self, widget, opt, *args):
         shaper_freq_x = self.freq_xy_adj['shaper_freq_x'].get_value()
