@@ -3,7 +3,6 @@ import gi
 
 gi.require_version("Gtk", "3.0")
 from gi.repository import Gtk
-from ks_includes.KlippyGcodes import KlippyGcodes
 from ks_includes.screen_panel import ScreenPanel
 
 
@@ -44,18 +43,18 @@ class Panel(ScreenPanel):
 
         functions = []
         pobox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
-        if self._printer.config_section_exists("stepper_z") \
-                and not self._printer.get_config_section("stepper_z")['endstop_pin'].startswith("probe"):
+
+        if "Z_ENDSTOP_CALIBRATE" in self._printer.available_commands:
             self._add_button("Endstop", "endstop", pobox)
             functions.append("endstop")
-        if self.probe:
+        if "PROBE_CALIBRATE" in self._printer.available_commands:
             self._add_button("Probe", "probe", pobox)
             functions.append("probe")
-        if self._printer.config_section_exists("bed_mesh") and "probe" not in functions:
+        if "BED_MESH_CALIBRATE" in self._printer.available_commands and "probe" not in functions:
             # This is used to do a manual bed mesh if there is no probe
             self._add_button("Bed mesh", "mesh", pobox)
             functions.append("mesh")
-        if "delta" in self._printer.get_config_section("printer")['kinematics']:
+        if "DELTA_CALIBRATE" in self._printer.available_commands:
             if "probe" in functions:
                 self._add_button("Delta Automatic", "delta", pobox)
                 functions.append("delta")
@@ -126,12 +125,12 @@ class Panel(ScreenPanel):
 
     def start_calibration(self, widget, method):
         self.labels['popover'].popdown()
+        self.buttons['start'].set_sensitive(False)
         if self._printer.get_stat("toolhead", "homed_axes") != "xyz":
-            self._screen._ws.klippy.gcode_script(KlippyGcodes.HOME)
-
+            self._screen._ws.klippy.gcode_script("G28")
         if method == "probe":
             self._move_to_position()
-            self._screen._ws.klippy.gcode_script(KlippyGcodes.PROBE_CALIBRATE)
+            self._screen._ws.klippy.gcode_script("PROBE_CALIBRATE")
         elif method == "mesh":
             self._screen._ws.klippy.gcode_script("BED_MESH_CALIBRATE")
         elif method == "delta":
@@ -139,7 +138,7 @@ class Panel(ScreenPanel):
         elif method == "delta_manual":
             self._screen._ws.klippy.gcode_script("DELTA_CALIBRATE METHOD=manual")
         elif method == "endstop":
-            self._screen._ws.klippy.gcode_script(KlippyGcodes.Z_ENDSTOP_CALIBRATE)
+            self._screen._ws.klippy.gcode_script("Z_ENDSTOP_CALIBRATE")
 
     def _move_to_position(self):
         x_position = y_position = None
@@ -218,19 +217,13 @@ class Panel(ScreenPanel):
         logging.info(f"Moving to X:{x_position} Y:{y_position}")
         self._screen._ws.klippy.gcode_script(f'G0 X{x_position} Y{y_position} F3000')
 
-    def process_busy(self, busy):
-        if busy:
-            for button in self.buttons:
-                self.buttons[button].set_sensitive(False)
-        elif self._printer.get_stat("manual_probe", "is_active"):
+    def activate(self):
+        if self._printer.get_stat("manual_probe", "is_active"):
             self.buttons_calibrating()
         else:
             self.buttons_not_calibrating()
 
     def process_update(self, action, data):
-        if action == "notify_busy":
-            self.process_busy(data)
-            return
         if action == "notify_status_update":
             if self._printer.get_stat("toolhead", "homed_axes") != "xyz":
                 self.widgets['zposition'].set_text("Z: ?")
@@ -262,17 +255,17 @@ class Panel(ScreenPanel):
         self.distance = distance
 
     def move(self, widget, direction):
-        self._screen._ws.klippy.gcode_script(KlippyGcodes.testz_move(f"{direction}{self.distance}"))
+        self._screen._ws.klippy.gcode_script(f"TESTZ Z={direction}{self.distance}")
 
     def abort(self, widget):
         logging.info("Aborting calibration")
-        self._screen._ws.klippy.gcode_script(KlippyGcodes.ABORT)
+        self._screen._ws.klippy.gcode_script("ABORT")
         self.buttons_not_calibrating()
         self._screen._menu_go_back()
 
     def accept(self, widget):
         logging.info("Accepting Z position")
-        self._screen._ws.klippy.gcode_script(KlippyGcodes.ACCEPT)
+        self._screen._ws.klippy.gcode_script("ACCEPT")
 
     def buttons_calibrating(self):
         self.buttons['start'].get_style_context().remove_class('color3')
